import { UnsignedEvent, EventTemplate } from 'nostr-tools'
import { SignedEvent } from '../../types'
import {
  LoginMethodStrategy,
  LoginMethodOperations
} from './loginMethodStrategy'
import { LoginMethod } from '../../store/auth/types'
import { NostrLoginStrategy } from './NostrLoginStrategy'
import { PrivateKeyStrategy } from './PrivateKeyStrategy'

export class LoginMethodContext implements LoginMethodOperations {
  private strategy: LoginMethodStrategy

  constructor(loginMethod?: LoginMethod) {
    switch (loginMethod) {
      case LoginMethod.nostrLogin:
        this.strategy = new NostrLoginStrategy()
        break
      case LoginMethod.privateKey:
        this.strategy = new PrivateKeyStrategy()
        break
      default:
        this.strategy = new LoginMethodStrategy()
        break
    }
  }

  nip04Encrypt(receiver: string, content: string): Promise<string> {
    return this.strategy.nip04Encrypt(receiver, content)
  }
  nip04EDecrypt(sender: string, content: string): Promise<string> {
    return this.strategy.nip04EDecrypt(sender, content)
  }
  nip44Encrypt(receiver: string, content: string): Promise<string> {
    return this.strategy.nip44Encrypt(receiver, content)
  }
  nip44EDecrypt(sender: string, content: string): Promise<string> {
    return this.strategy.nip44EDecrypt(sender, content)
  }
  signEvent(event: UnsignedEvent | EventTemplate): Promise<SignedEvent> {
    return this.strategy.signEvent(event)
  }
}
